summaryrefslogtreecommitdiff
path: root/deps/npm/node_modules
diff options
context:
space:
mode:
Diffstat (limited to 'deps/npm/node_modules')
-rw-r--r--deps/npm/node_modules/chownr/package.json10
-rw-r--r--deps/npm/node_modules/fstream-npm/fstream-npm.js14
-rw-r--r--deps/npm/node_modules/fstream-npm/node_modules/fstream-ignore/package.json4
-rw-r--r--deps/npm/node_modules/fstream-npm/package.json11
-rw-r--r--deps/npm/node_modules/mkdirp/README.markdown7
-rw-r--r--deps/npm/node_modules/mkdirp/index.js25
-rw-r--r--deps/npm/node_modules/mkdirp/package.json12
-rw-r--r--deps/npm/node_modules/node-gyp/legacy/common.gypi15
-rw-r--r--deps/npm/node_modules/node-gyp/legacy/tools/gyp/pylib/gyp/generator/make.py10
-rw-r--r--deps/npm/node_modules/node-gyp/lib/node-gyp.js19
-rw-r--r--deps/npm/node_modules/node-gyp/node_modules/ansi/package.json7
-rw-r--r--deps/npm/node_modules/node-gyp/node_modules/glob/package.json7
-rw-r--r--deps/npm/node_modules/node-gyp/package.json16
-rw-r--r--deps/npm/node_modules/uid-number/package.json9
14 files changed, 107 insertions, 59 deletions
diff --git a/deps/npm/node_modules/chownr/package.json b/deps/npm/node_modules/chownr/package.json
index 10e52c4dc..bb321f8ad 100644
--- a/deps/npm/node_modules/chownr/package.json
+++ b/deps/npm/node_modules/chownr/package.json
@@ -20,6 +20,7 @@
"scripts": {
"test": "tap test/*.js"
},
+ "license": "BSD",
"_npmUser": {
"name": "isaacs",
"email": "i@izs.me"
@@ -31,8 +32,11 @@
"node": "*"
},
"_engineSupported": true,
- "_npmVersion": "1.1.13",
- "_nodeVersion": "v0.7.7-pre",
+ "_npmVersion": "1.1.23",
+ "_nodeVersion": "v0.7.10-pre",
"_defaultsLoaded": true,
- "_from": "chownr"
+ "dist": {
+ "shasum": "51d18189d9092d5f8afd623f3288bfd1c6bf1a62"
+ },
+ "_from": "../chownr"
}
diff --git a/deps/npm/node_modules/fstream-npm/fstream-npm.js b/deps/npm/node_modules/fstream-npm/fstream-npm.js
index 39429d18c..43c0f169f 100644
--- a/deps/npm/node_modules/fstream-npm/fstream-npm.js
+++ b/deps/npm/node_modules/fstream-npm/fstream-npm.js
@@ -26,14 +26,20 @@ function Packer (props) {
this.bundleLinks = props.bundleLinks
this.package = props.package
+ // only do the magic bundling stuff for the node_modules folder that
+ // lives right next to a package.json file.
+ this.bundleMagic = this.parent &&
+ this.parent.packageRoot &&
+ this.basename === "node_modules"
+
// in a node_modules folder, resolve symbolic links to
// bundled dependencies when creating the package.
- props.follow = this.follow = this.basename === "node_modules"
+ props.follow = this.follow = this.bundleMagic
// console.error("follow?", this.path, props.follow)
if (this === this.root ||
this.parent &&
- this.parent.basename === "node_modules" &&
+ this.parent.bundleMagic &&
this.basename.charAt(0) !== ".") {
this.readBundledLinks()
}
@@ -85,7 +91,7 @@ Packer.prototype.applyIgnores = function (entry, partial, entryObj) {
if (entry === "package.json") return true
// special rules. see below.
- if (entry === "node_modules") return true
+ if (entry === "node_modules" && this.packageRoot) return true
// some files are *never* allowed under any circumstances
if (entry === ".git" ||
@@ -110,7 +116,7 @@ Packer.prototype.applyIgnores = function (entry, partial, entryObj) {
// To prevent infinite cycles in the case of cyclic deps that are
// linked with npm link, even in a bundle, deps are only bundled
// if they're not already present at a higher level.
- if (this.basename === "node_modules") {
+ if (this.bundleMagic) {
// bubbling up. stop here and allow anything the bundled pkg allows
if (entry.indexOf("/") !== -1) return true
diff --git a/deps/npm/node_modules/fstream-npm/node_modules/fstream-ignore/package.json b/deps/npm/node_modules/fstream-npm/node_modules/fstream-ignore/package.json
index 53f37281a..ed82c6543 100644
--- a/deps/npm/node_modules/fstream-npm/node_modules/fstream-ignore/package.json
+++ b/deps/npm/node_modules/fstream-npm/node_modules/fstream-ignore/package.json
@@ -35,8 +35,8 @@
"node": "*"
},
"_engineSupported": true,
- "_npmVersion": "1.1.16",
- "_nodeVersion": "v0.7.8-pre",
+ "_npmVersion": "1.1.23",
+ "_nodeVersion": "v0.7.10-pre",
"_defaultsLoaded": true,
"_from": "fstream-ignore@~0.0.5"
}
diff --git a/deps/npm/node_modules/fstream-npm/package.json b/deps/npm/node_modules/fstream-npm/package.json
index 83acd0d82..fa46c74e6 100644
--- a/deps/npm/node_modules/fstream-npm/package.json
+++ b/deps/npm/node_modules/fstream-npm/package.json
@@ -6,7 +6,7 @@
},
"name": "fstream-npm",
"description": "fstream class for creating npm packages",
- "version": "0.0.6",
+ "version": "0.1.0",
"repository": {
"type": "git",
"url": "git://github.com/isaacs/fstream-npm.git"
@@ -16,19 +16,20 @@
"fstream-ignore": "~0.0.5",
"inherits": ""
},
+ "license": "BSD",
"_npmUser": {
"name": "isaacs",
"email": "i@izs.me"
},
- "_id": "fstream-npm@0.0.6",
+ "_id": "fstream-npm@0.1.0",
"devDependencies": {},
"optionalDependencies": {},
"engines": {
"node": "*"
},
"_engineSupported": true,
- "_npmVersion": "1.1.16",
- "_nodeVersion": "v0.7.8-pre",
+ "_npmVersion": "1.1.23",
+ "_nodeVersion": "v0.7.10-pre",
"_defaultsLoaded": true,
- "_from": "fstream-npm@0 >=0.0.5"
+ "_from": "fstream-npm@0.1"
}
diff --git a/deps/npm/node_modules/mkdirp/README.markdown b/deps/npm/node_modules/mkdirp/README.markdown
index b4dd75fdc..40de04f71 100644
--- a/deps/npm/node_modules/mkdirp/README.markdown
+++ b/deps/npm/node_modules/mkdirp/README.markdown
@@ -3,6 +3,8 @@ mkdirp
Like `mkdir -p`, but in node.js!
+[![build status](https://secure.travis-ci.org/substack/node-mkdirp.png)](http://travis-ci.org/substack/node-mkdirp)
+
example
=======
@@ -33,6 +35,9 @@ permission string `mode`.
If `mode` isn't specified, it defaults to `0777 & (~process.umask())`.
+`cb(err, made)` fires with the error or the first directory `made`
+that had to be created, if any.
+
mkdirp.sync(dir, mode)
----------------------
@@ -41,6 +46,8 @@ with octal permission string `mode`.
If `mode` isn't specified, it defaults to `0777 & (~process.umask())`.
+Returns the first directory that had to be created, if any.
+
install
=======
diff --git a/deps/npm/node_modules/mkdirp/index.js b/deps/npm/node_modules/mkdirp/index.js
index 871488f63..874b31095 100644
--- a/deps/npm/node_modules/mkdirp/index.js
+++ b/deps/npm/node_modules/mkdirp/index.js
@@ -3,14 +3,12 @@ var fs = require('fs');
module.exports = mkdirP.mkdirp = mkdirP.mkdirP = mkdirP;
-function mkdirP (p, mode, f) {
+function mkdirP (p, mode, f, made) {
if (typeof mode === 'function' || mode === undefined) {
f = mode;
mode = 0777 & (~process.umask());
}
-
- // secret passalong argument.
- var made = arguments[3] || null;
+ if (!made) made = null;
var cb = f || function () {};
if (typeof mode === 'string') mode = parseInt(mode, 8);
@@ -29,10 +27,21 @@ function mkdirP (p, mode, f) {
});
break;
+ case 'EISDIR':
+ case 'EPERM':
+ // Operation not permitted or already is a dir.
+ // This is the error you get when trying to mkdir('c:/')
+ // on windows, or mkdir('/') on unix. Make sure it's a
+ // dir by falling through to the EEXIST case.
+ case 'EROFS':
+ // a read-only file system.
+ // However, the dir could already exist, in which case
+ // the EROFS error will be obscuring a EEXIST!
+ // Fallthrough to that case.
case 'EEXIST':
fs.stat(p, function (er2, stat) {
// if the stat fails, then that's super weird.
- // let the original EEXIST be the failure reason.
+ // let the original error be the failure reason.
if (er2 || !stat.isDirectory()) cb(er, made)
else cb(null, made);
});
@@ -45,13 +54,11 @@ function mkdirP (p, mode, f) {
});
}
-mkdirP.sync = function sync (p, mode) {
+mkdirP.sync = function sync (p, mode, made) {
if (mode === undefined) {
mode = 0777 & (~process.umask());
}
-
- // secret passalong argument
- var made = arguments[2] || null;
+ if (!made) made = null;
if (typeof mode === 'string') mode = parseInt(mode, 8);
p = path.resolve(p);
diff --git a/deps/npm/node_modules/mkdirp/package.json b/deps/npm/node_modules/mkdirp/package.json
index 2a40503c5..2a393e97a 100644
--- a/deps/npm/node_modules/mkdirp/package.json
+++ b/deps/npm/node_modules/mkdirp/package.json
@@ -1,7 +1,7 @@
{
"name": "mkdirp",
"description": "Recursively mkdir, like `mkdir -p`",
- "version": "0.3.0",
+ "version": "0.3.2",
"author": {
"name": "James Halliday",
"email": "mail@substack.net",
@@ -20,7 +20,7 @@
"test": "tap test/*.js"
},
"devDependencies": {
- "tap": "0.2"
+ "tap": "~0.2.4"
},
"license": "MIT/X11",
"engines": {
@@ -30,15 +30,15 @@
"name": "isaacs",
"email": "i@izs.me"
},
- "_id": "mkdirp@0.3.0",
+ "_id": "mkdirp@0.3.2",
"dependencies": {},
"optionalDependencies": {},
"_engineSupported": true,
- "_npmVersion": "1.1.13",
- "_nodeVersion": "v0.7.7-pre",
+ "_npmVersion": "1.1.23",
+ "_nodeVersion": "v0.7.10-pre",
"_defaultsLoaded": true,
"dist": {
- "shasum": "a3cc6816e78b84f570caf9d95cb7368dc5d0bab8"
+ "shasum": "bebd1a16759571a6bd30f89a7edffc38ad442881"
},
"_from": "../mkdirp"
}
diff --git a/deps/npm/node_modules/node-gyp/legacy/common.gypi b/deps/npm/node_modules/node-gyp/legacy/common.gypi
index f67e6da3e..8b3e7c2e7 100644
--- a/deps/npm/node_modules/node-gyp/legacy/common.gypi
+++ b/deps/npm/node_modules/node-gyp/legacy/common.gypi
@@ -8,6 +8,13 @@
'library%': 'static_library', # allow override to 'shared_library' for DLL/.so builds
'component%': 'static_library', # NB. these names match with what V8 expects
'msvs_multi_core_compile': '0', # we do enable multicore compiles, but not using the V8 way
+
+ # Enable V8's post-mortem debugging only on unix flavors.
+ 'conditions': [
+ ['OS != "win"', {
+ 'v8_postmortem_support': 'true'
+ }]
+ ],
},
'target_defaults': {
@@ -25,7 +32,7 @@
'VCCLCompilerTool': {
'RuntimeLibrary': 1, # static debug
'Optimization': 0, # /Od, no optimization
- 'MinimalRebuild': 'true',
+ 'MinimalRebuild': 'false',
'OmitFramePointers': 'false',
'BasicRuntimeChecks': 3, # /RTC1
},
@@ -42,6 +49,8 @@
}],
['OS=="solaris"', {
'cflags': [ '-fno-omit-frame-pointer' ],
+ # pull in V8's postmortem metadata
+ 'ldflags': [ '-Wl,-z,allextract' ]
}],
['strict_aliasing!="true"', {
'cflags': [ '-fno-strict-aliasing' ],
@@ -137,7 +146,6 @@
'ldflags': [ '-m32' ],
}],
[ 'OS=="linux"', {
- 'cflags': [ '-ansi' ],
'ldflags': [ '-rdynamic' ],
}],
[ 'OS=="solaris"', {
@@ -149,6 +157,7 @@
],
}],
['OS=="mac"', {
+ 'defines': ['_DARWIN_USE_64_BIT_INODE=1'],
'xcode_settings': {
'ALWAYS_SEARCH_USER_PATHS': 'NO',
'GCC_CW_ASM_SYNTAX': 'NO', # No -fasm-blocks
@@ -161,7 +170,7 @@
'GCC_VERSION': '4.2',
'GCC_WARN_ABOUT_MISSING_NEWLINE': 'YES', # -Wnewline-eof
'PREBINDING': 'NO', # No -Wl,-prebind
- 'MACOSX_DEPLOYMENT_TARGET': '10.5',
+ 'MACOSX_DEPLOYMENT_TARGET': '10.5', # -mmacosx-version-min=10.5
'USE_HEADERMAP': 'NO',
'OTHER_CFLAGS': [
'-fno-strict-aliasing',
diff --git a/deps/npm/node_modules/node-gyp/lib/node-gyp.js b/deps/npm/node_modules/node-gyp/lib/node-gyp.js
index 33c5445a6..ad92e817a 100644
--- a/deps/npm/node_modules/node-gyp/lib/node-gyp.js
+++ b/deps/npm/node_modules/node-gyp/lib/node-gyp.js
@@ -112,6 +112,25 @@ proto.parseArgv = function parseOpts (argv) {
}, this)
this.todo = commands
+
+ // support for inheriting config env variables from npm
+ var npm_config_prefix = 'npm_config_'
+ Object.keys(process.env).forEach(function (name) {
+ if (name.indexOf(npm_config_prefix) !== 0) return
+ var val = process.env[name]
+ if (name === npm_config_prefix + 'loglevel') {
+ // "loglevel" is a special case; check for "verbose"
+ if (val === 'verbose') {
+ this.opts.verbose = true
+ }
+ } else {
+ // take the config name and check if it's one that node-gyp cares about
+ name = name.substring(npm_config_prefix.length)
+ if (name in this.configDefs) {
+ this.opts[name] = val
+ }
+ }
+ }, this)
}
/**
diff --git a/deps/npm/node_modules/node-gyp/node_modules/ansi/package.json b/deps/npm/node_modules/node-gyp/node_modules/ansi/package.json
index afefb7545..d8a5c2987 100644
--- a/deps/npm/node_modules/node-gyp/node_modules/ansi/package.json
+++ b/deps/npm/node_modules/node-gyp/node_modules/ansi/package.json
@@ -41,11 +41,8 @@
"dependencies": {},
"optionalDependencies": {},
"_engineSupported": true,
- "_npmVersion": "1.1.21",
- "_nodeVersion": "v0.7.9-pre",
+ "_npmVersion": "1.1.23",
+ "_nodeVersion": "v0.7.10-pre",
"_defaultsLoaded": true,
- "dist": {
- "shasum": "1bbdab47714665c8484fb62da53f4553c6baec73"
- },
"_from": "ansi@0.0.x"
}
diff --git a/deps/npm/node_modules/node-gyp/node_modules/glob/package.json b/deps/npm/node_modules/node-gyp/node_modules/glob/package.json
index eb89f6c3e..3589c368f 100644
--- a/deps/npm/node_modules/node-gyp/node_modules/glob/package.json
+++ b/deps/npm/node_modules/node-gyp/node_modules/glob/package.json
@@ -36,11 +36,8 @@
"_id": "glob@3.1.9",
"optionalDependencies": {},
"_engineSupported": true,
- "_npmVersion": "1.1.21",
- "_nodeVersion": "v0.7.9-pre",
+ "_npmVersion": "1.1.23",
+ "_nodeVersion": "v0.7.10-pre",
"_defaultsLoaded": true,
- "dist": {
- "shasum": "a81b5dd6244b74b277cc1e825f25ebc511854525"
- },
"_from": "glob@3"
}
diff --git a/deps/npm/node_modules/node-gyp/package.json b/deps/npm/node_modules/node-gyp/package.json
index 6319fafe7..83be556c7 100644
--- a/deps/npm/node_modules/node-gyp/package.json
+++ b/deps/npm/node_modules/node-gyp/package.json
@@ -10,8 +10,8 @@
"bindings",
"gyp"
],
- "version": "0.4.3",
- "installVersion": 7,
+ "version": "0.4.5",
+ "installVersion": 8,
"author": {
"name": "Nathan Rajlich",
"email": "nathan@tootallnate.net",
@@ -32,7 +32,7 @@
"graceful-fs": "1",
"fstream": "~0.1.13",
"minimatch": "0.2.x",
- "mkdirp": "0.3.0",
+ "mkdirp": "0.3",
"nopt": "1",
"request": "2.9.x",
"rimraf": "2",
@@ -47,15 +47,15 @@
"name": "isaacs",
"email": "i@izs.me"
},
- "_id": "node-gyp@0.4.3",
+ "_id": "node-gyp@0.4.5",
"devDependencies": {},
"optionalDependencies": {},
"_engineSupported": true,
- "_npmVersion": "1.1.21",
- "_nodeVersion": "v0.7.9-pre",
+ "_npmVersion": "1.1.23",
+ "_nodeVersion": "v0.7.10-pre",
"_defaultsLoaded": true,
"dist": {
- "shasum": "8d45b9b77800f40f27a6445d01d99161942d9b36"
+ "shasum": "9ddb9c4218322fd3d6b9771b27c236c4e5965e3b"
},
- "_from": "node-gyp@~0.4.1"
+ "_from": "node-gyp@~0.4.4"
}
diff --git a/deps/npm/node_modules/uid-number/package.json b/deps/npm/node_modules/uid-number/package.json
index 3c0592cb6..babe6f43e 100644
--- a/deps/npm/node_modules/uid-number/package.json
+++ b/deps/npm/node_modules/uid-number/package.json
@@ -18,17 +18,18 @@
"engines": {
"node": "*"
},
+ "license": "BSD",
"_npmUser": {
"name": "isaacs",
"email": "i@izs.me"
},
"_id": "uid-number@0.0.3",
"_engineSupported": true,
- "_npmVersion": "1.1.12",
- "_nodeVersion": "v0.7.7-pre",
+ "_npmVersion": "1.1.23",
+ "_nodeVersion": "v0.7.10-pre",
"_defaultsLoaded": true,
"dist": {
- "shasum": "be40aeab1db6ba45d2344d4ed6015109fc9d98d4"
+ "shasum": "cefb0fa138d8d8098da71a40a0d04a8327d6e1cc"
},
- "_from": "uid-number@0.0.3"
+ "_from": "../uid-number"
}
diff --git a/deps/npm/node_modules/node-gyp/legacy/tools/gyp/pylib/gyp/generator/make.py b/deps/npm/node_modules/node-gyp/legacy/tools/gyp/pylib/gyp/generator/make.py
index e93cb0331..ec0519081 100644
--- a/deps/npm/node_modules/node-gyp/legacy/tools/gyp/pylib/gyp/generator/make.py
+++ b/deps/npm/node_modules/node-gyp/legacy/tools/gyp/pylib/gyp/generator/make.py
@@ -525,9 +525,9 @@ d_files := $(wildcard $(foreach f,$(all_deps),$(depsdir)/$(f).d))
ifneq ($(d_files),)
# Rather than include each individual .d file, concatenate them into a
# single file which make is able to load faster. We split this into
# commands that take 1000 files at a time to avoid overflowing the
# command line.
- $(shell cat $(wordlist 1,1000,$(d_files)) > $(depsdir)/all.deps)
+ $(shell cat $(wordlist 1,512,$(d_files)) > $(depsdir)/all.deps)
%(generate_all_deps)s
# make looks for ways to re-generate included makefiles, but in our case, we
# don't have a direct way. Explicitly telling make that it has nothing to do
@@ -2128,10 +2128,10 @@ def GenerateOutput(target_list, target_dicts, data, params):
if generator_flags.get('auto_regeneration', True):
WriteAutoRegenerationRule(params, root_makefile, makefile_name, build_files)
# Write the rule to load dependencies. We batch 1000 files at a time to
# avoid overflowing the command line.
all_deps = ""
- for i in range(1001, num_outputs, 1000):
+ for i in range(513, num_outputs, 512):
all_deps += ("""
ifneq ($(word %(start)d,$(d_files)),)
$(shell cat $(wordlist %(start)d,%(end)d,$(d_files)) >> $(depsdir)/all.deps)
@@ -2142,7 +2142,7 @@ def GenerateOutput(target_list, target_dicts, data, params):
ifneq ($(word %(last)d,$(d_files)),)
$(error Found unprocessed dependency files (gyp didn't generate enough rules!))
endif
-""" % { 'last': ((num_outputs / 1000) + 1) * 1000 + 1 }
+""" % { 'last': ((num_outputs / 512) + 1) * 512 + 1 }
root_makefile.write(SHARED_FOOTER % { 'generate_all_deps': all_deps })
@@ -525,9 +525,9 @@ d_files := $(wildcard $(foreach f,$(all_deps),$(depsdir)/$(f).d))
# Rather than include each individual .d file, concatenate them into a
# single file which make is able to load faster. We split this into
- # commands that take 1000 files at a time to avoid overflowing the
+ # commands that take 512 files at a time to avoid overflowing the
# command line.
@@ -2128,10 +2128,10 @@ def GenerateOutput(target_list, target_dicts, data, params):
if generator_flags.get('auto_regeneration', True):
WriteAutoRegenerationRule(params, root_makefile, makefile_name, build_files)
- # Write the rule to load dependencies. We batch 1000 files at a time to
+ # Write the rule to load dependencies. We batch 512 files at a time to
# avoid overflowing the command line.
all_deps = ""